@@ -1,5 +1,6 @@
 package Beam::Wire::Moose;
-$Beam::Wire::Moose::VERSION = '0.004';
+# ABSTRACT: Dependency Injection with extra Moose features
+$Beam::Wire::Moose::VERSION = '0.005';
 use Moose;
 use Moose::Meta::Class;
 extends 'Beam::Wire';
@@ -27,11 +28,11 @@ __END__
 
 =head1 NAME
 
-Beam::Wire::Moose
+Beam::Wire::Moose - Dependency Injection with extra Moose features
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -53,10 +54,6 @@ version 0.004
 Beam::Wire::Moose is a subclass of Beam::Wire that adds support for Moose-specific
 features.
 
-=head1 NAME
-
-Beam::Wire::Moose - Dependency Injection with extra Moose features
-
 =head1 SERVICE CONFIG
 
 =head2 with
